import os

from codecs import open
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))


requires = [
    'requests>=2.22.0',
    'lxml>=4.4.1',
    'cachelib',
    'appdirs'
]


about = {}
with open(os.path.join(here, 'translate_it', '__version__.py'),
          'r', 'utf-8') as f:
    exec(f.read(), about)


setup(

    name=about['__name__'],
    version=about['__version__'],
    description=about['__description__'],
    python_requires='>=3.5',
    packages=find_packages(exclude=('tests', 'tests.*')),
    zip_safe=False,
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    entry_points={
        'console_scripts': [
            'translate_it = translate_it.translate_it:command_line_runner'
        ]
    },
    install_requires=requires,
)



__name__ = 'translate-it'
__version__ = '0.2.0'
__description__ = 'translate it for me.'
__license__ = 'Apache 2.0'
__author__ = 'wen'
__author_email__ = 'w_angzhiwen@163.com'
__url__ = 'https://github.com/suadminwen/translate'



import re
import requests
import appdirs
from lxml import etree
from argparse import ArgumentParser
from cachelib import FileSystemCache, NullCache

CACHE_DIR = appdirs.user_cache_dir('translate_it')
CACHE_ENTRY_MAX = 128

cache = FileSystemCache(CACHE_DIR, CACHE_ENTRY_MAX, default_timeout=0)


def get_content(words):
    res = requests.get(f'https://dict.youdao.com/w/{words}')
    res.raise_for_status()
    return res.text


def parse(response):
    html = etree.HTML(response)
    contents = html.xpath('//div[@id="results-contents"]')[0]
    container = contents.xpath('//div[@class="trans-container"]/ul')
    results = []
    if len(container) > 0:
        results = container[0].xpath('li/text()')
        if len(results) > 0:
            results = [result for result in results if result.strip()]
        else:
            for word in container[0].xpath('p'):
                klass = word.xpath('string(span[1])')
                value = word.xpath('string(span[2]/a)')
                results.append(f'{klass} {value}')
    return results


def tran(words):
    words = ' '.join(words)
    results = cache.get(words)
    if not results:
        response = get_content(words)
        results = [re.sub(r'\s', '', result) for result in parse(response)]
        if results:
            cache.set(words, results)

    return results


def get_parser():

    parser = ArgumentParser(description='To help you translate')
    parser.add_argument('words', metavar='WORDS', type=str,
                        nargs='*', help='the words to translate')

    return parser


def command_line_runner():
    parser = get_parser()
    args = vars(parser.parse_args())

    if not args['words']:
        parser.print_help()
        return

    for word in tran(args['words']):
        print(word)


if __name__ == '__main__':
    command_line_runner()
